Method: Consular::Core.capture!
- Defined in:
- lib/consular/core.rb
.capture! ⇒ Hash
Captures the current terminal settings for the system. It will return a hash format like that of Consular::DSL so that Consular can write it back out into a Termfile.
59 60 61 |
# File 'lib/consular/core.rb', line 59 def capture! raise NotImplementedError, "capture! is currently unavailable for this core." end |